:mod:`euphorie.content.solution`
===============================

.. automodule:: euphorie.content.solution


Classes
-------

.. autoclass:: Solution
   :members:

Interfaces
----------

.. autointerface:: ISolution
   :members:


Views
-----

.. autoclass:: View
